<?php
/*
  Plugin Name: Bridge for WooCommerce - disallow same attendee email
  Plugin URI: https://tickera.com
  Description: Disallow duplicate attendee emails
  Author: Tickera
  Author URI: https://tickera.com
  Version: 1.0
  TextDomain: tc
  Domain Path: /languages/

  Copyright 2019 Tickera (https://tickera.com)
 */
if (!defined('ABSPATH')) {
    exit;
} // Exit if accessed directly

if (!class_exists('TC_bridge_for_woocommerce_disallow_same_attendee_email')) {
    class TC_bridge_for_woocommerce_disallow_same_attendee_email
    {
        public $version		 = '1.0';
        public $title		 = 'Bridge for WooCommerce - disallow same attendee email';
        public $name		 = 'bridge_for_woocommerce_disallow_same_attendee_email';
        public $dir_name	 = 'bridge_for_woocommerce_disallow_same_attendee_email';
        public $location	 = 'plugins';
        public $plugin_dir	 = '';
        public $plugin_url	 = '';

        public function __construct()
        {
            $this->init_vars();
            add_action('woocommerce_after_checkout_validation', array($this, 'disallow_duplicate_attendee_emails'), 10, 1);
        }

        public function init_vars()
        {
            //setup proper directories
            if (defined('WP_PLUGIN_URL') && defined('WP_PLUGIN_DIR') && file_exists(WP_PLUGIN_DIR . '/' . $this->dir_name . '/' . basename(__FILE__))) {
                $this->location		 = 'subfolder-plugins';
                $this->plugin_dir	 = WP_PLUGIN_DIR . '/' . $this->dir_name . '/';
                $this->plugin_url	 = plugins_url('/', __FILE__);
            } elseif (defined('WP_PLUGIN_URL') && defined('WP_PLUGIN_DIR') && file_exists(WP_PLUGIN_DIR . '/' . basename(__FILE__))) {
                $this->location		 = 'plugins';
                $this->plugin_dir	 = WP_PLUGIN_DIR . '/';
                $this->plugin_url	 = plugins_url('/', __FILE__);
            } elseif (is_multisite() && defined('WPMU_PLUGIN_URL') && defined('WPMU_PLUGIN_DIR') && file_exists(WPMU_PLUGIN_DIR . '/' . basename(__FILE__))) {
                $this->location		 = 'mu-plugins';
                $this->plugin_dir	 = WPMU_PLUGIN_DIR;
                $this->plugin_url	 = WPMU_PLUGIN_URL;
            } else {
                wp_die(sprintf(__('There was an issue determining where %s is installed. Please reinstall it.', 'tc'), $this->title));
            }
        }

        function has_duplicates($array) {
          $duplicates_array = array();
          foreach ($array as $val) {
            if (++$duplicates_array[$val] > 1) {
              return true;
          }
        }
          return false;
        }

        public function disallow_duplicate_attendee_emails($data){
          $all_attendee_emails = array();

          $target_fields = isset($_POST['owner_data_owner_email_post_meta']) ? $_POST['owner_data_owner_email_post_meta'] : false;

          foreach($target_fields as $array_email){
            foreach($array_email as $email){
              if(!empty($email)){
                $all_attendee_emails[] = $email;
              }
            }
          }

          if(!empty($all_attendee_emails)){
            if($this->has_duplicates($all_attendee_emails)){
                wc_add_notice(__('Same attendee e-mails are not allowed.', 'tc'), 'error');
            }
          }

        }
    }
}

$TC_bridge_for_woocommerce_disallow_same_attendee_email = new TC_bridge_for_woocommerce_disallow_same_attendee_email();
